@@ -1,4 +1,4 @@
-from ext.utils.resp_utils import resp_result
+from skyext.utils.resp_utils import resp_result
 
 from model1.goods.dao import GoodsDao
 
